__all__ = [
    "jd_rds_refund_model",
    "jd_rds_trade_model",
    "jd_source_buyer_model",
    "jd_source_item_model",
    "jd_member_info_model",
    "jd_one_member_sync_model",
    "jd_user_data_model",
    "jd_user_pin_model",
]



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2026-03-10 00:00:00
@LastEditTime: 2026-03-10 00:00:00
@LastEditors: HuangJianYi
@Description: 京东售后退款表
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class JdRdsRefundModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(JdRdsRefundModel, self).__init__(JdRdsRefund, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class JdRdsRefund:
    def __init__(self):
        super(JdRdsRefund, self).__init__()
        self.serviceId = 0  # 售后服务Id
        self.orderId = 0  # 订单Id
        self.state = ''  # 订单状态
        self.orderType = ''  # 订单类型
        self.buId = ''  # 商家Id
        self.pin = ''  # 买家PIN(后期此字段将废弃, 建议使用openId)
        self.xid = ''  # 买家XID
        self.created = '1970-01-01 00:00:00.000'  # 交易创建时间
        self.modified = '1970-01-01 00:00:00.000'  # 交易修改时间
        self.responseJson = {}  # 详情(JSON)
        self.hashcode = ''  # 用来做数据校验的字段
        self.version = ''  # 交易版本号
        self.pushCreated = '1970-01-01 00:00:00.000'  # 数据第一次推送的时间
        self.pushModified = '1970-01-01 00:00:00.000'  # 数据最新一次推送的时间

    @classmethod
    def get_field_list(self):
        return [
            'serviceId', 'orderId', 'state', 'orderType', 'buId', 'pin', 'xid', 'created', 'modified', 'responseJson',
            'hashcode', 'version', 'pushCreated', 'pushModified'
        ]

    @classmethod
    def get_primary_key(self):
        return "serviceId"

    def __str__(self):
        return "jd_rds_refund_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2026-03-10 00:00:00
@LastEditTime: 2026-03-10 00:00:00
@LastEditors: HuangJianYi
@Description: 京东商品表
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class JdSourceItemModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(JdSourceItemModel, self).__init__(JdSourceItem, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class JdSourceItem:
    def __init__(self):
        super(JdSourceItem, self).__init__()
        self.wareId = 0  # 商品id
        self.shopId = 0  # 店铺id
        self.venderId = 0  # 商家id
        self.title = ''  # 商品名称
        self.categoryId = 0  # 3级类目ID，来源于类目接口返回ID
        self.wareStatus = 0  # 商品状态
        self.outerId = ''  # 商品外部ID,商家自行设置的ID（便于关联京东商品）
        self.logo = ''  # 商品主图。该字段返回的不是完整的图片jpg链接，需要拼接https://img10.360buyimg.com/imgzone/前缀
        self.marketPrice = 0.0  # 市场价单位：元
        self.costPrice = 0.0  # 成本价单位：元
        self.jdPrice = 0.0  # 京东价单位：元
        self.stockNum = 0  # 总库存数
        self.transportId = 0  # 运费模板ID
        self.skuJson = {}  # sku详情(JSON)
        self.offlineTime = '1900-01-01 00:00:00.000'  # 最后下架时间
        self.onlineTime = '1900-01-01 00:00:00.000'  # 最后上架时间
        self.modified = '1900-01-01 00:00:00.000'  # 商品最后一次修改时间
        self.created = '1900-01-01 00:00:00.000'  # 商品创建时间

    @classmethod
    def get_field_list(self):
        return [
            'wareId', 'shopId', 'venderId', 'title', 'categoryId', 'wareStatus', 'outerId', 'logo',
            'marketPrice', 'costPrice', 'jdPrice', 'stockNum', 'transportId', 'skuJson', 'offlineTime',
            'onlineTime', 'modified', 'created'
        ]

    @classmethod
    def get_primary_key(self):
        return "wareId"

    def __str__(self):
        return "jd_source_item_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 09:39:45
@LastEditTime: 2026-03-19 19:38:14
@LastEditors: HuangJianYi
@Description: 
"""

# 此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class CdpJobTemplateModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(CdpJobTemplateModel, self).__init__(CdpJobTemplate, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class CdpJobTemplate:
    def __init__(self):
        super(CdpJobTemplate, self).__init__()
        self.id = 0  # id
        self.job_code = ""  # 作业代码(对应函数名)
        self.job_desc = ""  # 作业描述
        self.engineer_code = ""  # 工程代码
        self.job_type = 0  # 任务类型(1-商家 2-店铺)
        self.tag_name = ""  # 标签名称(多个逗号分隔)
        self.sort_index = 0  # 排序
        self.is_release = 0  # 是否发布（1-是 0-否）
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间



    @classmethod
    def get_field_list(self):
        return [
            'id', 'job_code', 'job_desc', 'engineer_code', 'job_type', 'tag_name', 'sort_index', 'is_release', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cdp_job_template_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2026-03-10 00:00:00
@LastEditTime: 2026-03-10 00:00:00
@LastEditors: HuangJianYi
@Description: 京东买家用户表
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class JdSourceBuyerModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(JdSourceBuyerModel, self).__init__(JdSourceBuyer, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class JdSourceBuyer:
    def __init__(self):
        super(JdSourceBuyer, self).__init__()
        self.xid = ''  # xid
        self.pin = ''  # pin
        self.open_uid = ''  # open_id_buyer
        self.store_id = ''  # 店铺id
        self.vender_id = ''  # 商家id
        self.status = ''  # 显示会员的状态，normal正常，blacklist黑名单
        self.grade = 0  # 会员等级
        self.province = ''  # 省份
        self.city = ''  # 城市
        self.last_trade_time = '1900-01-01 00:00:00.000'  # 最后交易的日期
        self.item_num = 0  # 购买的宝贝件数
        self.trade_amount = 0.0  # 交易的金额
        self.trade_count = 0  # 交易成功的次数
        self.item_close_count = 0  # 交易关闭的宝贝件数
        self.close_trade_amount = 0.0  # 交易关闭金额
        self.close_trade_count = 0  # 交易关闭的笔数
        self.avg_price = 0.0  # 平均客单价
        self.modify_time = '1900-01-01 00:00:00.000'  # 修改时间
        self.create_time = '1900-01-01 00:00:00.000'  # 创建时间

    @classmethod
    def get_field_list(self):
        return [
            'xid', 'pin', 'open_uid', 'store_id', 'vender_id', 'status', 'grade', 'province', 'city',
            'last_trade_time', 'item_num', 'trade_amount', 'trade_count', 'item_close_count', 'close_trade_amount',
            'close_trade_count', 'avg_price', 'modify_time', 'create_time'
        ]

    @classmethod
    def get_primary_key(self):
        return "xid"

    def __str__(self):
        return "jd_source_buyer_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2026-03-18 18:30:00
@Description: CDP作业信息模型
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *
# 在文件顶部添加模块级缓存
_job_monitor_cache = {}
import threading
_job_cache_lock = threading.Lock()

class CdpJobInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(CdpJobInfoModel, self).__init__(CdpJobInfo, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

    def get_jobs(self, engineer_code=None):
        """
        获取已发布的作业列表
        
        :param engineer_code: 工程代码
        :param business_id: 商家ID
        :param store_id: 店铺ID
        :return: 作业列表
        """
        where_conditions = ["is_release=1", "progress_type in (0,1)"]
        params = []

        if engineer_code:
            where_conditions.append("engineer_code=%s")
            params.append(engineer_code)

        where_sql = " AND ".join(where_conditions)

        return self.get_dict_list(where_sql, order_by="create_date ASC", params=params)

    def monitor_job(self, job_id, run_desc='持续处理中', interval_seconds=60):
        """
        监控作业 - 为了避免数据库压力，添加1分钟间隔
        :param job_id: 作业ID
        :param run_desc: 运行描述描述
        :return: 更新结果
        """
        current_time = time.time()
        # 先判断模块级别缓存
        local_cache_key = f"cdp_job_monitor_local:{job_id}"
        with _job_cache_lock:
            last_local_time = _job_monitor_cache.get(local_cache_key, 0)
            # 如果本地时间判断通过，直接返回
            if current_time - float(last_local_time) < interval_seconds:
                return True

        update_sqls = ["run_last_date=NOW()"]
        params = []
        if run_desc:
            update_sqls.append("run_desc=%s")
            params.append(run_desc)
        params.append(job_id)
        result = self.update_table(",".join(update_sqls), "id=%s", params=params)

        # 更新缓存时间
        with _job_cache_lock:
            _job_monitor_cache[local_cache_key] = current_time

        return result

    def start_job(self, job_id, run_desc='开始处理'):
        """
        开始作业
        :param job_id: 作业ID
        :param run_desc: 运行描述描述
        :return: 更新结果
        """
        update_sqls = ["progress_type=1", "run_start_date=NOW()", "run_last_date=NOW()"]
        params = []
        if run_desc:
            update_sqls.append("run_desc=%s")
            params.append(run_desc)
        params.append(job_id)
        return self.update_table(
            ",".join(update_sqls),
            "id=%s",
            params=params
        )

    def stop_job(self, job_id, run_desc='停止处理'):
        """
        停止作业
        :param job_id: 作业ID
        :param run_desc: 运行描述描述
        :return: 更新结果
        """
        update_sqls = ["progress_type=0", "run_last_date=NOW()"]
        params = []
        if run_desc:
            update_sqls.append("run_desc=%s")
            params.append(run_desc)
        params.append(job_id)
        return self.update_table(
            ",".join(update_sqls),
            "id=%s",
            params=params
        )

    def complete_job(self, job_id, run_desc='完成处理'):
        """
        完成作业
        
        :param job_id: 作业ID
        :param run_desc: 运行结果描述
        :return: 更新结果
        """
        update_sqls = ["progress_type=2", "run_end_date=NOW()", "run_last_date=NOW()"]
        params = []
        if run_desc:
            update_sqls.append("run_desc=%s")
            params.append(run_desc)
        params.append(job_id)
        return self.update_table(
            ",".join(update_sqls),
            "id=%s",
            params=params
        )


class CdpJobInfo:
    """CDP作业信息实体类"""

    def __init__(self):
        super(CdpJobInfo, self).__init__()
        self.id = 0  # id
        self.business_id = 0  # 商家标识
        self.store_id = 0  # 店铺标识
        self.job_code = ""  # 作业代码(对应函数名)
        self.engineer_code = ""  # 工程代码
        self.is_release = 0  # 是否发布（1-是 0-否）
        self.progress_type = 0  # 进度类型(0-未开始 1-进行中 2-已完成)
        self.extend_info = {} # 扩展信息json
        self.run_desc = ""  # 运行结果描述
        self.run_start_date = "1970-01-01 00:00:00.000"  # 开始运行时间
        self.run_end_date = "1970-01-01 00:00:00.000"  # 结束运行时间
        self.run_last_date = "1970-01-01 00:00:00.000"  # 最近运行时间
        self.create_date = "1970-01-01 00:00:00.000"  # 创建时间
        self.modify_date = "1970-01-01 00:00:00.000"  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'store_id', 'job_code', 'engineer_code',
            'is_release', 'progress_type', 'extend_info', 'run_desc', 'run_start_date',
            'run_end_date', 'run_last_date', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cdp_job_info_tb"
